@@ -9,9 +9,9 @@
 #include "lily-guile.hh"
 #include "break-align-item.hh"
 #include "dimensions.hh"
-#include "p-score.hh"
+#include "paper-score.hh"
 #include "paper-def.hh"
-#include "p-col.hh"
+#include "paper-column.hh"
 
 
 /*
